@@ -5,4 +5,4 @@ IFS=$'\n\t'
 set -x
 
 dotnet new console --no-restore
-dotnet publish -r "$(../runtime-id)" /p:PublishReadyToRun=true
+dotnet publish -r "$(../runtime-id --sdk)" /p:PublishReadyToRun=true
